import {DataGrid, type DataGridProps, type GridColumnVisibilityModel} from '@mui/x-data-grid'
import {Stack, Box, Button} from '@mui/material'
import React, {useState, useEffect} from 'react'
import Cookies from 'js-cookie'

interface CustomDataGridProps extends DataGridProps {
  hasCoordinates?: boolean
}

export const CustomDataGrid = ({hasCoordinates = false, columns = [], ...props}: CustomDataGridProps) => {
  const initialShowCoordinates = Cookies.get('showCoordinates') === 'true'
  const [showCoordinates, setShowCoordinates] = useState(initialShowCoordinates)
  const [columnVisibilityModel, setColumnVisibilityModel] = useState<GridColumnVisibilityModel>({
    latitude: showCoordinates,
    longitude: showCoordinates,
  })

  useEffect(() => {
    if (hasCoordinates) {
      setColumnVisibilityModel({
        latitude: showCoordinates,
        longitude: showCoordinates,
      })
      Cookies.set('showCoordinates', String(showCoordinates))
    }
  }, [showCoordinates, hasCoordinates])

  const toggleCoordinates = () => {
    setShowCoordinates((prev) => !prev)
  }

  return (
    <Stack spacing={2}>
      <DataGrid {...props} columns={columns} columnVisibilityModel={hasCoordinates ? columnVisibilityModel : undefined} onColumnVisibilityModelChange={hasCoordinates ? (model) => setColumnVisibilityModel(model) : undefined} />

      {hasCoordinates && (
        <Box sx={{mb: 2}}>
          <Button variant="contained" onClick={toggleCoordinates}>
            {showCoordinates ? 'Скрыть координаты' : 'Показать координаты'}
          </Button>
        </Box>
      )}
    </Stack>
  )
}
